summaryrefslogtreecommitdiff
path: root/gtk/gtkclist.h
diff options
context:
space:
mode:
authorOwen Taylor <owt1@cornell.edu>1998-01-31 03:33:02 +0000
committerOwen Taylor <otaylor@src.gnome.org>1998-01-31 03:33:02 +0000
commitb38b6f5f0f84d37e6dd44f2adcc2d6b1efc1ec21 (patch)
tree7c925701d8525e826fe9abf743fa585a12cf08ce /gtk/gtkclist.h
parentdb628b3ca02269fd0a817b750dc29c8322c3782e (diff)
downloadgtk+-b38b6f5f0f84d37e6dd44f2adcc2d6b1efc1ec21.tar.gz
- Conformity to new reference counting schemes - Font and color
Fri Jan 30 22:28:09 1998 Owen Taylor <owt1@cornell.edu> * gtk/gtkclist.{c,h}: - Conformity to new reference counting schemes - Font and color information is no-longer taken from the (possibly unitialized) style before the widget is realized, but is obtained when needed. (Fixes problems with non-default styles) - white_gc => base_gc where appropriate - Handle graphics expose events correctly (or as correctly as anywhere else) so that scrolling when overlapped works.
Diffstat (limited to 'gtk/gtkclist.h')
-rw-r--r--gtk/gtkclist.h21
1 files changed, 13 insertions, 8 deletions
diff --git a/gtk/gtkclist.h b/gtk/gtkclist.h
index 33d2a6cf5d..618ceb3664 100644
--- a/gtk/gtkclist.h
+++ b/gtk/gtkclist.h
@@ -135,7 +135,7 @@ struct _GtkCList
guint8 vscrollbar_policy;
guint8 hscrollbar_policy;
/* xor GC for the verticle drag line */
GdkGC *xor_gc;
/* gc for drawing unselected cells */
@@ -177,6 +177,8 @@ struct _GtkCListColumn
gint width;
GtkJustification justification;
+
+ gint width_set : 1;
};
struct _GtkCListRow
@@ -188,6 +190,9 @@ struct _GtkCListRow
GdkColor background;
gpointer data;
+
+ gint fg_set : 1;
+ gint bg_set : 1;
};
/* Cell Structures */
@@ -195,7 +200,7 @@ struct _GtkCellText
{
GtkCellType type;
- gint verticle;
+ gint vertical;
gint horizontal;
gchar *text;
@@ -205,7 +210,7 @@ struct _GtkCellPixmap
{
GtkCellType type;
- gint verticle;
+ gint vertical;
gint horizontal;
GdkPixmap *pixmap;
@@ -216,7 +221,7 @@ struct _GtkCellPixText
{
GtkCellType type;
- gint verticle;
+ gint vertical;
gint horizontal;
gchar *text;
@@ -229,7 +234,7 @@ struct _GtkCellWidget
{
GtkCellType type;
- gint verticle;
+ gint vertical;
gint horizontal;
GtkWidget *widget;
@@ -239,7 +244,7 @@ struct _GtkCell
{
GtkCellType type;
- gint verticle;
+ gint vertical;
gint horizontal;
union {
@@ -379,13 +384,13 @@ void gtk_clist_set_background (GtkCList * clist,
gint row,
GdkColor * color);
/* this sets a horizontal and verticle shift for drawing
* the contents of a cell; it can be positive or negitive; this is
* partuculary useful for indenting items in a column */
void gtk_clist_set_shift (GtkCList * clist,
gint row,
gint column,
- gint verticle,
+ gint vertical,
gint horizontal);
/* append returns the index of the row you just added, making
@@ -135,7 +135,7 @@ struct _GtkCList
guint8 vscrollbar_policy;
guint8 hscrollbar_policy;
- /* xor GC for the verticle drag line */
+ /* xor GC for the vertical drag line */
GdkGC *xor_gc;
/* gc for drawing unselected cells */
@@ -379,13 +384,13 @@ void gtk_clist_set_background (GtkCList * clist,
gint row,
GdkColor * color);
-/* this sets a horizontal and verticle shift for drawing
+/* this sets a horizontal and vertical shift for drawing
* the contents of a cell; it can be positive or negitive; this is
* partuculary useful for indenting items in a column */